==> ChIPanalyser_1.0.0.tar.gz: ChIPanalyser/man/boundMolecules_-.Rd <==
\name{boundMolecules<-}
\alias{boundMolecules<-}
\alias{boundMolecules<--methods}


\title{
Setter method for the \code{boundMolecules} slot in a
\code{\link{occupancyProfileParameters}} object.
}
\description{
Setter method for the \code{boundMolecules} slot in a
\code{\link{occupancyProfileParameters}} object.
}
\usage{
boundMolecules(object)<-value
}

\arguments{
    \item{object}{
    \code{object} is a \code{\link{occupancyProfileParameters}} object.
    }
    \item{value}{
    \code{value} is a positive integer or vector of positive
    integers describing the number ofmolecules bound to DNA.
    Defaut value is 1000.
    }
}
\details{
Default value: 1000
When computing occupancy (\code{\link{computeOccupancy}}),
a value for the number of bound Molecules to DNA is needed.
This value can be updated and set in a
\code{\link{occupancyProfileParameters}} object.
If the number of molecules is unknown,
it is possible to infer this value with \code{\link{computeOptimal}}.
We strongly encourage to set values when building a
\code{\link{occupancyProfileParameters}} object.
}
\value{
Returns a \code{\link{occupancyProfileParameters}} object with an updated
value for \code{boundMolecules}.
}
\references{
Zabet NR, Adryan B (2015) Estimating binding properties of transcription
factors from genome-wide binding profiles. Nucleic Acids Res., 43, 84–94.
}
\author{
Patrick C.N. Martin <pm16057@essex.ac.uk>
}

\examples{
# Building occupancyProfileParameters object
OPP <- occupancyProfileParameters()
# Setting new boundMolecules value in OPP
boundMolecules(OPP) <- 5000
#Checking value in whole object
OPP
#Checking single value by slot accessor
boundMolecules(OPP)

}

==> ChIPanalyser_1.9.1.tar.gz: ChIPanalyser/man/boundMolecules_-.Rd <==
\name{boundMolecules<-}


\alias{boundMolecules<-}


\title{
Setter method for the \code{boundMolecules} slot in a
\code{\link{parameterOptions}} object.
}
\description{
Setter method for the \code{boundMolecules} slot in a
\code{\link{parameterOptions}} object.
}
\usage{
boundMolecules(object)<-value
}

\arguments{
    \item{object}{
    \code{object} is a \code{\link{parameterOptions}} object.
    }
    \item{value}{
    \code{value} is a positive integer or vector of positive
    integers describing the number ofmolecules bound to DNA.
    Defaut value is 1000.
    }
}
\details{
Default value: 1000
When computing occupancy (\code{\link{computeOccupancy}}),
a value for the number of bound Molecules to DNA is needed.
This value can be updated and set in a
\code{\link{parameterOptions}} object.
If the number of molecules is unknown,
it is possible to infer this value with \code{\link{computeOptimal}}.
We strongly encourage to set values when building a
\code{\link{parameterOptions}} object.
}
\value{
Returns a \code{\link{parameterOptions}} object with an updated
value for \code{boundMolecules}.
}
\references{
Zabet NR, Adryan B (2015) Estimating binding properties of transcription
factors from genome-wide binding profiles. Nucleic Acids Res., 43, 84–94.
}
\author{
Patrick C.N. Martin <pm16057@essex.ac.uk>
}

\examples{
# Building parameterOptions object
OPP <- parameterOptions()
# Setting new boundMolecules value in OPP
boundMolecules(OPP) <- 5000
#Checking value in whole object
OPP
#Checking single value by slot accessor
boundMolecules(OPP)

}
